pub enum RegistryMethod {
Register {
name: String,
host: String,
port: u16,
protocol: Option<String>,
description: Option<String>,
namespace: Option<String>,
},
List {
active_only: Option<bool>,
},
Get {
name: String,
},
Update {
name: String,
host: Option<String>,
port: Option<u16>,
protocol: Option<String>,
description: Option<String>,
namespace: Option<String>,
},
Delete {
name: String,
},
Ping {
name: String,
},
Reload,
}Expand description
Auto-generated method enum for schema extraction
Variants
Register
Register a new backend
Fields
List
List all registered backends
Get
Get a specific backend by name
Update
Update an existing backend
Fields
Delete
Delete a backend
Ping
Ping a backend to update its last_seen timestamp
Reload
Reload the configuration file
Implementations
Sourceimpl RegistryMethod
impl RegistryMethod
pub fn all_method_names() -> &'static [&'static str]
Sourceimpl RegistryMethod
impl RegistryMethod
Sourcepub fn method_schemas() -> Vec<MethodSchema>
pub fn method_schemas() -> Vec<MethodSchema>
Get per-method schema info including params, return types, and content hashes
Note: This method has O(1) schema lookup cost after first call due to caching.